Changelog
=========

v0.5.0
------
* no new features, just updating packaging
* add conda-forge support
* add zenodo DOI citation support
* add github action workflows
* add trivial test file

v0.4.4
------
* create pure python packages
* include .whl file
* package as python3 only

v0.4.3
------
* improve help(pygrin)
* improve html at https://pygrin.readthedocs.io
* use google docstrings again

v0.4.1
------
* update function parameters for sphinx automodapi

v0.4.0
------
* sphinx documentation
* `plot_principal_plt` -> `plot_principal_planes`

v0.3.0
------
* renamed `pitch()` to `period()` to avoid stepping on the name.
* improve readme
* fix `pylint` warnings
* fix `pep257` warnings
* fix `pyroma` warnings

v0.2.0
------
* improve description
* add `hyperbolic_secant_profile_index`
* fix importing, update for new names

v0.2.0
------
* fix typos
* change status to alpha
